# spyProt ![Python package](https://github.com/ilbsm/spyProt/workflows/Python%20package/badge.svg)

Rapid protein overview from multiple databases (RCSB, PDBe, UniProt etc.)

Includes the ilbsm_database_downloader used to download data from [ILBSM databases](https://jsulkowska.cent.uw.edu.pl/) such as: 
- [Knotprot](https://knotprot.cent.uw.edu.pl/)
- [LassoProt](https://lassoprot.cent.uw.edu.pl/)
- [Genus](https://genus.fuw.edu.pl/)

Have a look at tests to see how to use it.
